LengthUnit enum

Inheritance
Implemented types
Available extensions

Values

meter → const LengthUnit
const LengthUnit('m')
kilometer → const LengthUnit
const LengthUnit('km')
hectometer → const LengthUnit
const LengthUnit('hm')
dekameter → const LengthUnit
const LengthUnit('dam')
decimeter → const LengthUnit
const LengthUnit('dm')
centimeter → const LengthUnit
const LengthUnit('cm')
milimeter → const LengthUnit
const LengthUnit('mm')
micrometer → const LengthUnit
const LengthUnit('µm')
nanometer → const LengthUnit
const LengthUnit('nm')
gigameter → const LengthUnit
const LengthUnit('Gm')
megameter → const LengthUnit
const LengthUnit('Mm')
angstrom → const LengthUnit
const LengthUnit('Å')
inch → const LengthUnit
const LengthUnit('in')
const LengthUnit('ft')
yard → const LengthUnit
const LengthUnit('yd')
mile → const LengthUnit
const LengthUnit('mi')
nauticalMile → const LengthUnit
const LengthUnit('nmi')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sym String
final
symbol String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LengthUnit>
A constant List of the values in this enum, in order of their declaration.